abessrpca" object.This function provides estimated
coefficients from a fitted "abessrpca" object.
# S3 method for abessrpca
coef(object, support.size = NULL, sparse = TRUE, ...)A list with length(support.size) number of dgCMatrix,
each of which is the estimation the sparse component.
An "abessrpca" project.
An integer vector specifies
the sparse matrix fitted at given support.size to be returned.
If support.size = NULL, then the sparse matrix with
the least tuning value would be returned.
Default: support.size = NULL.
A logical value, specifying whether the coefficients should be
presented as sparse matrix or not. Default: sparse = TRUE.
Other arguments.