abesspca" objectPrints the fitted model and returns it invisibly.
# S3 method for abesspca
print(x, digits = max(5, getOption("digits") - 5), ...)No return value, called for side effects
A "abesspca" object.
Minimum number of significant digits to be used.
additional print arguments
Print a data.frame with three columns:
the first column is support size of model;
the second column is the explained variance of model;
the last column is the percent of explained variance of model.
print.abesspca,
coef.abesspca,
plot.abesspca.